@@ -1,4 +1,5 @@
 """isort test wide fixtures and configuration"""
+
 import os
 from pathlib import Path
 
@@ -26,3 +27,8 @@ def test_path():
 @pytest.fixture
 def src_path():
     return Path(SRC_DIR).resolve()
+
+
+@pytest.fixture
+def examples_path():
+    return Path(TEST_DIR).resolve() / "example_projects"
